summaryrefslogtreecommitdiffstats
path: root/Source/cmExtraSublimeTextGenerator.h
diff options
context:
space:
mode:
Diffstat (limited to 'Source/cmExtraSublimeTextGenerator.h')
-rw-r--r--Source/cmExtraSublimeTextGenerator.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/Source/cmExtraSublimeTextGenerator.h b/Source/cmExtraSublimeTextGenerator.h
index 1735b75..fe8832f 100644
--- a/Source/cmExtraSublimeTextGenerator.h
+++ b/Source/cmExtraSublimeTextGenerator.h
@@ -69,9 +69,12 @@ private:
const char* compiler,
std::set<std::string>& includeDirs,
std::set<std::string>& defines, bool firstTarget);
- /** Extracts -D compile flags from a variable */
- void ExtractDefines(const char* value, bool check,
- std::set<std::string> &defines);
+ /**
+ * Extracts compile flags from a variable.
+ * flag would typically be "-D" or "-I"
+ */
+ void ExtractFlags(const char* value, const std::string& flag,
+ std::set<std::string> &defines);
};
#endif